==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/OpenStackPlatformStatusFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OpenStackPlatformStatusFluent<A extends io.fabric8.openshift.api.model.OpenStackPlatformStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiServerInternalIP();
  public A withApiServerInternalIP(java.lang.String apiServerInternalIP);
  public java.lang.Boolean hasApiServerInternalIP();
  
  /**
   * Method is deprecated. use withApiServerInternalIP instead.
   */
  @java.lang.Deprecated
  public A withNewApiServerInternalIP(java.lang.String arg0);
  public java.lang.String getCloudName();
  public A withCloudName(java.lang.String cloudName);
  public java.lang.Boolean hasCloudName();
  
  /**
   * Method is deprecated. use withCloudName instead.
   */
  @java.lang.Deprecated
  public A withNewCloudName(java.lang.String arg0);
  public java.lang.String getIngressIP();
  public A withIngressIP(java.lang.String ingressIP);
  public java.lang.Boolean hasIngressIP();
  
  /**
   * Method is deprecated. use withIngressIP instead.
   */
  @java.lang.Deprecated
  public A withNewIngressIP(java.lang.String arg0);
  public java.lang.String getNodeDNSIP();
  public A withNodeDNSIP(java.lang.String nodeDNSIP);
  public java.lang.Boolean hasNodeDNSIP();
  
  /**
   * Method is deprecated. use withNodeDNSIP instead.
   */
  @java.lang.Deprecated
  public A withNewNodeDNSIP(java.lang.String arg0);
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/OpenStackPlatformStatusFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface OpenStackPlatformStatusFluent<A extends io.fabric8.openshift.api.model.OpenStackPlatformStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiServerInternalIP();
  public A withApiServerInternalIP(java.lang.String apiServerInternalIP);
  public java.lang.Boolean hasApiServerInternalIP();
  
  /**
   * Method is deprecated. use withApiServerInternalIP instead.
   */
  @java.lang.Deprecated
  public A withNewApiServerInternalIP(java.lang.String arg0);
  public java.lang.String getCloudName();
  public A withCloudName(java.lang.String cloudName);
  public java.lang.Boolean hasCloudName();
  
  /**
   * Method is deprecated. use withCloudName instead.
   */
  @java.lang.Deprecated
  public A withNewCloudName(java.lang.String arg0);
  public java.lang.String getIngressIP();
  public A withIngressIP(java.lang.String ingressIP);
  public java.lang.Boolean hasIngressIP();
  
  /**
   * Method is deprecated. use withIngressIP instead.
   */
  @java.lang.Deprecated
  public A withNewIngressIP(java.lang.String arg0);
  public java.lang.String getNodeDNSIP();
  public A withNodeDNSIP(java.lang.String nodeDNSIP);
  public java.lang.Boolean hasNodeDNSIP();
  
  /**
   * Method is deprecated. use withNodeDNSIP instead.
   */
  @java.lang.Deprecated
  public A withNewNodeDNSIP(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
